@@ -6,7 +6,7 @@ use warnings;
 use Tk;
 use Tk::Balloon;
 
-use version; our $VERSION = qv('0.0.3');    # PBP
+use version; our $VERSION = qv('0.0.5');    # PBP
 
 # Usage:
 # perl enter_presets.pl
@@ -323,6 +323,16 @@ This program is called internally by
 L<SudokuTrainer|Games::Sudoku::Trainer::pod::sudokutrainer.pod> when 
 the user selects the option I<Enter manually> to create the initial puzzle.
 
+L<Games::Sudoku::Trainer::pod::sudokutrainer.pod>
+
+L<Games::Sudoku::Trainer::pod/sudokutrainer.pod>
+
+L<Games/Sudoku/Trainer/pod/sudokutrainer.pod>
+
+L<sudokutrainer.pl>
+
+L<sudokutrainer>
+
 =head1 DESCRIPTION 
 
 B<enter_presets> initially displays an empty Sudoku board. Values may be 
